#
# spec file for package systemd-ui
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           systemd-ui
Url:            http://www.freedesktop.org/wiki/Software/systemd
Version:        3
Release:        2.4
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  update-desktop-files
BuildRequires:  vala-devel
BuildRequires:  xz
BuildRequires:  pkgconfig(dbus-1) >= 1.3.2
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) > 2.26
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libnotify)
Summary:        Graphical front-end for systemd
License:        GPL-2.0+
Group:          System/Base
Requires:       systemd
Obsoletes:      systemd-gtk <= 44
Provides:       systemd-gtk
Source0:        http://www.freedesktop.org/software/systemd/%{name}-%{version}.tar.xz

# Upstream First - Policy:
# Never add any patches to this package without the upstream commit id
# in the patch. Any patches added here without a very good reason to make
# an exception will be silently removed with the next version update.
# PATCH-FIX-UPSTREAM systemd-ui-notification-clarification.patch dimstar@opensuse.org -- Fix ambiguity between `GLib.Notification' and `Notify.Notification'
Patch0:         systemd-ui-notification-clarification.patch

%description
Graphical front-end for systemd system and service manager.

%prep
%autosetup -p1

%build
export V=1
%configure \
  CFLAGS="%{optflags}"

make %{?_smp_mflags}

%install
%makeinstall
%suse_update_desktop_file systemadm -r System Monitor

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%{_bindir}/systemadm
%{_bindir}/systemd-gnome-ask-password-agent
%{_mandir}/man1/systemadm.1*
%{_datadir}/applications/*.desktop

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3:
  + systemadm: filter on slices and scopes too.
  + Make various things resizable and scrollable.
  + Update color scheme.
  + gnome-ask-password-agent updates.
- Add systemd-ui-notification-clarification.patch.
- Drop fix-desktop.patch: fixed upstream.
* Mon Apr  8 2013 fcrozat@suse.com
- Update to version 2:
  + build with gtk3 (drop port-gtk3.patch, merged)
  + build with libgee 0.8 (drop build-gee08.patch, merged)
- Switch BuildRequires to pkgconfig(gee-0.8)
* Fri Nov 30 2012 fcrozat@suse.com
- Add build-gee08.patch: allow to build with libgee 0.8 if
  installed.
- Add port-gtk3.patch: build with gtk3.
- Add automake/autoconf to BuildRequires and switch to gtk3.
* Mon Sep 24 2012 fcrozat@suse.com
- Rename package from systemd-gtk to systemd-ui.
- Update to version 1 of systemd-ui
- Drop fixppc.patch (merged upstream)
- Add fix-desktop.patch: add missing category and GenericName.
* Tue Apr  3 2012 dvaleev@suse.com
- apply ppc patch to systemd-gtk too (fixes build)
* Thu Mar 22 2012 fcrozat@suse.com
- Update fixppc.patch with upstream patches
- Add comments from upstream in
  0001-util-never-follow-symlinks-in-rm_rf_children.patch.
- Add logind-logout.patch: it should fix sudo / su with pam_systemd
  (bnc#746704).
* Mon Mar 19 2012 fcrozat@suse.com
- Add 0001-add-sparse-support-to-detect-endianness-bug.patch: fix
  endianness error, preventing journal to work properly on ppc.
- Add fixppc.patch: fix build and warnings on ppc.
* Mon Mar 19 2012 fcrozat@suse.com
- Add 0001-util-never-follow-symlinks-in-rm_rf_children.patch: fix
  CVE-2012-1174 (bnc#752281).
* Fri Mar 16 2012 fcrozat@suse.com
- Update to version 43:
  + Support optional initialization of the machine ID from the KVM
    or container configured UUID.
  + Support immediate reboots with "systemctl reboot -ff"
  + Show /etc/os-release data in systemd-analyze output
  + Many bugfixes for the journal, including endianess fixes and
    ensuring that disk space enforcement works
  + non-UTF8 strings are refused if used in configuration and unit
    files.
  + Register Mimo USB Screens as suitable for automatic seat
    configuration
  + Reorder configuration file lookup order. /etc now always
    overrides /run.
  + manpages for journal utilities.
- Drop fix-c++-compat.patch, no-tmpfs-fsck.patch,
  systemd-journald-fix-endianess-bug.patch.
- Requires util-linux >= 2.21 (needed to fix fsck on tmpfs).
* Mon Mar 12 2012 fcrozat@suse.com
- Add fix-c++-compat.patch: fix C++ compatibility error in header.
* Wed Feb 29 2012 fcrozat@suse.com
- Add systemd-journald-fix-endianess-bug.patch: fix journald not
  starting on ppc architecture.
- Add correct_plymouth_paths_and_conflicts.patch: ensure plymouth
  is correctly called and conflicts with bootsplash.
* Tue Feb 21 2012 fcrozat@suse.com
- Remove rsyslog listen.conf, handled directly by rsyslog now
  (bnc#747871).
* Mon Feb 20 2012 fcrozat@suse.com
- Update to version 43:
  + requires /etc/os-release, support for /etc/SuSE-release is no
    longer present.
  + Track class of PAM logins to distinguish greeters from normal
    user logins.
  + Various bug fixes.
* Sun Feb 19 2012 jengelh@medozas.de
- Use pkgconfig symbols for BuildRequires and specify version
* Fri Feb 17 2012 tittiatcoke@gmail.com
- Enable Plymouth integration.
  * Bootsplash related files will be moved to the bootsplash
    package
* Mon Feb 13 2012 fcrozat@suse.com
- Update to version 42:
  + Various bug fixes
  + Watchdog support for supervising services is now usable
  + Service start rate limiting is now configurable and can be
    turned off per service.
  + New CanReboot(), CanPowerOff() bus calls in systemd-logind
- Dropped fix-kmod-build.patch, fix-message-after-chkconfig.patch,
  is-enabled-non-existing-service.patch (merged upstream)
- Add libxslt1 / docbook-xsl-stylesheets as BuildRequires for
  manpage generation
* Thu Feb  9 2012 fcrozat@suse.com
- Update to version 41:
  + systemd binary is now installed in /lib/systemd (symlink for
  /bin/systemd is available now)
  + kernel modules are now loaded through libkmod
  + Watchdog support is now useful (not complete)
  + new kernel command line available to set system wide
    environment variable: systemd.setenv
  + journald capabilities set is now limited
  + SIGPIPE is ignored by default. This can be disabled with
    IgnoreSIGPIPE=no in unit files.
- Add fix-kmod-build.patch: fix build with libkmod
- Drop remote-fs-after-network.patch (merged upstream)
- Add dm-lvm-after-local-fs-pre-target.patch: ensure md / lvm
  /dmraid is started before mounting partitions, if fsck was
  disabled for them (bnc#733283).
- Update lsb-header patch to correctly disable heuristic if
  X-Systemd-RemainAfterExit is specified (whatever its value)
- Add fix-message-after-chkconfig.patch: don't complain if only
  sysv services are called in systemctl.
- Add is-enabled-non-existing-service.patch: fix error message when
  running is-enabled on non-existing service.
* Tue Feb  7 2012 fcrozat@suse.com
- Update to version 40:
  + reason why a service failed is now exposed in the"Result" D-Bus
    property.
  + Rudimentary service watchdog support (not complete)
  + Improve bootcharts, by immediatly changing argv[0] after
    forking to to reflect which process will be executed.
  + Various bug fixes.
- Add remote-fs-after-network.patch and update insserv patch:
  ensure remote-fs-pre.target is enabled and started before network
  mount points (bnc#744293).
- Ensure journald doesn't prevent syslogs to read from /proc/kmsg.
* Tue Jan 31 2012 fcrozat@suse.com
- Ensure systemd show service status when started behind bootsplash
  (bnc#736225).
- Disable core dump redirection to journal, not stable atm.
* Thu Jan 26 2012 fcrozat@suse.com
- Update modules_on_boot.patch to not cause failed state for
  systemd-modules-load.service (bnc#741481).
* Wed Jan 25 2012 fcrozat@suse.com
- Update to version 39:
  + New systemd-cgtop tool to show control groups by their resource
    usage.
  + Linking against libacl for ACLs is optional again.
  + If a group "adm" exists, journal files are automatically owned
    by them, thus allow members of this group full access to the
    system journal as well as all user journals.
  + The journal now stores the SELinux context of the logging
    client for all entries.
  + Add C++ inclusion guards to all public headers.
  + New output mode "cat" in the journal to print only text
    messages, without any meta data like date or time.
  + Include tiny X server wrapper as a temporary stop-gap to teach
    XOrg udev display enumeration (until XOrg supports udev
    hotplugging for display devices).
  + Add new systemd-cat tool for executing arbitrary programs with
    STDERR/STDOUT connected to the journal. Can also act as BSD
    logger replacement, and does so by default.
  + Optionally store all locally generated coredumps in the journal
    along with meta data.
  + systemd-tmpfiles learnt four new commands: n, L, c, b, for
    writing short strings to files (for usage for /sys), and for
    creating symlinks, character and block device nodes.
  + New unit file option ControlGroupPersistent= to make cgroups
    persistent.
  + Support multiple local RTCs in a sane way.
  + No longer monopolize IO when replaying readahead data on
    rotating disks.
  + Don't show kernel threads in systemd-cgls anymore, unless
    requested with new -k switch.
- Drop systemd-syslog_away_early_on_shutdown.patch: fixed upstream.
- Add fdupes to BuildRequires and use it at build time.
* Thu Jan 19 2012 tittiatcoke@gmail.com
- Make the systemd journal persistent by creating the
  /var/log/journal directory
* Wed Jan 18 2012 tittiatcoke@gmail.com
- Update to version 38 :
  - Bugfixes
  - Implementation of a Journal Utility Library
  - Implementation of a 128 Bit ID Utility Library
- 11 Patches integrated upstream
- Add systemd-syslog_away_early_on_shutdown.patch: make sure
  syslog socket goes away early during shutdown.
- Add listen.conf for rsyslog. This will ensure that it will still
  work fine with rsyslog and the new journal.
* Mon Jan  9 2012 fcrozat@suse.com
- Add fix-is-enabled.patch: ensure systemctl is-enabled work
  properly when systemd isn't running.
- Add logind-console.patch: do not bail logind if /dev/tty0 doesn't
  exist (bnc#733022, bnc#735047).
- Add sysctl-modules.patch: ensure sysctl is started after modules
  are loaded (bnc#725412).
- Fix warning in insserv patch.
- Update avoid-random-seed-cycle.patch with better upstream
  approach.
- Update storage-after-cryptsetup.patch to restart lvm before
  local-fs.target, not after it (bnc#740106).
- Increase pam-config dependency (bnc#713319).
* Wed Dec  7 2011 fcrozat@suse.com
- Remove storage-after-cryptsetup.service, add
  storage-after-cryptsetup.patch instead to prevent dependency
  cycle (bnc#722539).
- Add delay-fsck-cryptsetup-after-md-lvm-dmraid.patch: ensure
  fsck/cryptsetup is run after lvm/md/dmraid have landed
  (bnc#724912).
- Add cron-tty-pam.patch: Fix cron filling logs (bnc#731358).
- Add do_not_warn_pidfile.patch: Fix PID warning in logs
  (bnc#732912).
- Add mount-swap-log.patch: Ensure swap and mount output is
  redirected to default log target (rhb#750032).
- Add color-on-boot.patch: ensure colored status are displayed at
  boot time.
- Update modules_on_boot.patch to fix bnc#732041.
- Replace private_tmp_crash.patch with log_on_close.patch, better
  upstream fix for bnc#699829 and fix bnc#731719.
- Update vconsole patch to fix memleaks and crash (bnc#734527).
- Add handle-racy-daemon.patch: fix warnings with sendmail
  (bnc#732912).
- Add new-lsb-headers.patch: support PIDFile: and
  X-Systemd-RemainAfterExit: header in initscript (bnc#727771).
- Update bootsplash services to not start if vga= is missing from
  cmdline (bnc#727771)
- Add lock-opensuse.patch: disable /var/lock/{subsys,lockdev} and
  change default permissions on /var/lock (bnc#733523).
- Add garbage_collect_units: ensure error units are correctly
  garbage collected (rhb#680122).
- Add crypt-loop-file.patch: add support for crypt file loop
  (bnc#730496).
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov  4 2011 fcrozat@suse.com
- Fix rpm macros to only call presets on initial install
  (bnc#728104).
* Thu Oct 27 2011 fcrozat@suse.com
- Add no-tmpfs-fsck.patch: don't try to fsck tmpfs mountpoint
  (bnc#726791).
* Wed Oct 19 2011 fcrozat@suse.com
- Add avoid-random-seed-cycle.patch: fix dependency cycle between
  cryptsetup and random-seed-load (bnc#721666).
- Add crash-isolating.patch: fix crash when isolating a service.
- Fix bootsplash being killed too early.
- Fix some manpages not being redirected properly.
- Add storage-after-cryptsetup.service to restart lvm after
  cryptsetup. Fixes lvm on top of LUKS (bnc#724238).
* Fri Oct 14 2011 fcrozat@suse.com
- Recommends dbus-1-python, do not requires python (bnc#716939)
- Add private_tmp_crash.patch: prevent crash in debug mode
  (bnc#699829).
- Add systemctl-completion-fix.patch: fix incorrect bash completion
  with some commands (git).
* Wed Oct 12 2011 fcrozat@suse.com
- Shadow single sysv service, it was breaking runlevel 1.
- Add modules_on_boot.patch to handle /etc/sysconfig/kernel
  MODULES_ON_BOOT variable (bnc#721662).
* Wed Oct 12 2011 fcrozat@suse.com
- Update to release 37:
  - many bugfixes
  - ConditionCapability added, useful for containers.
  - locale mechanism got extend to kbd configuration for
    both X and the console
  - don't try to guess PID for SysV services anymore (bnc#723194)
- Drop detect-non-running.patch, logind-warning.patch.
- Rewrite systemd-sysv-convert in bash (bnc#716939)
* Tue Oct 11 2011 coolo@suse.com
- make sure updaters get in the /sbin/init from here - the sub package
  of the split package will decide which init wins in update case
* Tue Oct 11 2011 coolo@suse.com
- under openSUSE if it's not systemd, chances are good it's
  sysvinit
* Tue Oct 11 2011 coolo@suse.com
- do not list specific sbin_init providers
* Wed Oct  5 2011 fcrozat@suse.com
- Add logind-warning.patch: fix pam warning (bnc#716384)
* Fri Sep 30 2011 fcrozat@suse.com
- Update to version 36 :
  - many bugfixes
  - systemd now requires socket-activated syslog implementations
  - After=syslog.target is no longer needed in .service files
  - X-Interactive is ignored in LSB headers (was not working)
- Enable back insserv.conf parsing in systemd core and fix added
  dependencies (bnc#721428).
- Fix detection of LSB services status when running daemon
  (bnc#721426).
- Drop 0001-execute-fix-bus-serialization-for-commands.patch,
  fix-reload.patch
* Thu Sep 29 2011 fcrozat@suse.com
- Add services to stop bootsplash at end of startup and start it at
  beginning of shutdown.
- Fix bootsplash call and ensure dependencies are set right.
* Thu Sep 29 2011 fcrozat@suse.com
- Add detect-non-running.patch: fix assertion when running
  systemctl under non systemd system (git).
- Requires presets branding package.
- Improve macros a little bit.
* Mon Sep 26 2011 fcrozat@suse.com
- Merge migration rpm macros into service_add/service_del macros.
- Use systemd presets in rpm macros
- Add fix-reload.patch: handle daemon-reload and start condition
  properly (bnc#719221).
* Fri Sep 23 2011 fcrozat@suse.com
- Add systemd-splash / bootsplash-startup.service: enable
  bootsplash at startup.
* Fri Sep 16 2011 fcrozat@suse.com
- Create -32bit package (bnc#713319)
* Mon Sep 12 2011 fcrozat@suse.com
- Do not mask localnet service, it is not yet handled by systemd.
  (bnc#716746)
* Fri Sep  9 2011 fcrozat@suse.com
- Add revert_insserv_conf_parsing.patch and systemd-insserv_conf:
  remove insserv.conf parsing from systemd and use generator
  instead.
- put back default.target creation at package install and remove
  inittab generator, Yast2 is now able to create it.
* Thu Sep  1 2011 fcrozat@novell.com
- Update to version 34:
  * Bugfixes
  * optionaly apply cgroup attributes to cgroups systemd creates
  * honour sticky bit when trimming cgroup trees
  * improve readahead
- Add libacl-devel as BuildRequires (needed for systemd-uaccess)
- Add some %%{nil} to systemd.macros to fix some build issues.
- Fix dbus assertion
- move gtk part to its own package, to reduce bootstrapping
  (bnc#713981).
* Fri Aug 26 2011 fcrozat@suse.com
- Update compose_table patch to use two separate loadkeys call,
  compose table overflows otherwise (spotted by Werner Fink).
* Wed Aug 24 2011 fcrozat@novell.com
- Add tty1.patch: ensure passphrase are handled before starting
  gettty on tty1.
- Add inittab generator, creating default.target at startup based
  on /etc/inittab value.
- No longer try to create /etc/systemd/system/default.target at
  initial package install (bnc#707418)
- Fix configuration path used for systemd user manager.
- Ensure pam-config output is no display in install script.
- Remove buildrequires on vala, no longer needed.
* Fri Aug 19 2011 fcrozat@suse.com
- Handle disable_capslock, compose table and kbd_rate
- Add rpm macros.systemd file.
- Do not disable klogd, it has its own service now.
- Handle kexec correctly (bnc#671673).
- Disable preload services, they are conflicting with systemd.
* Fri Aug 19 2011 fcrozat@suse.com
- enable pam_systemd module, using pam-config.
* Thu Aug 18 2011 aj@suse.de
- Fix crash with systemctl enable.
* Tue Aug 16 2011 fcrozat@suse.com
- Fix localfs.service to no cause cycle and starts it after
  local-fs.target.
* Thu Aug  4 2011 fcrozat@suse.com
- Remove root-fsck.patch, mkinitrd will use the same path as
  dracut.
- Add systemd-cryptsetup.patch: don't complain on "none" option in
  crypttab.
- Add systemd-cryptsetup-query.patch: block boot until passphrase
  is typed.
* Wed Aug  3 2011 fcrozat@suse.com
- Add root-fsck.patch: do not run fsck on / if it is rw
- Ship a non null localfs.service, fixes static mount points not
  being mounted properly.
* Wed Aug  3 2011 aj@suse.de
- Update to version 33:
  * optimizations and bugfixes.
  * New PrivateNetwork= service setting which allows you to shut off
    networking for a specific service (i.e. all routable network
    interfaces will disappear for that service).
  * Merged insserv-parsing.patch and bash-completion-restart.patch
    patches.
* Tue Aug  2 2011 fcrozat@suse.com
- Add insserv-parsing.patch: read/parse insserv.conf.
- Add bash-completion-restart.patch: fix restart service list
  (bnc#704782).
* Mon Aug  1 2011 aj@suse.de
- Split up devel package.
- restart logind after upgrade.
- Adjust rpmlintrc for changes.
* Fri Jul 29 2011 aj@suse.de
- Update to version 32:
  * bugfixes
  * improve selinux setup
* Thu Jul 28 2011 aj@suse.de
- Update to version 31:
  * rewrite of enable/disable code: New features systemctl --runtime,
    systemctl mask, systemctl link and presets.
  * sd-daemon is now shared library.
* Tue Jul 19 2011 aj@suse.de
- Update to version 30:
  + Logic from pam_systemd has been moved to new systemd-login.
  + VT gettys are autospawn only when needed
  + Handle boot.local/halt.local on SUSE distribution
  + add support for systemctl --root
* Wed Jun 29 2011 fcrozat@suse.com
- Make sure to not start kbd initscript, it is handled by systemd
  natively.
* Fri Jun 17 2011 fcrozat@novell.com
- version 29:
  + enable chkconfig support in systemctl for openSUSE.
  + systemctl: plug a leak upon create_symlink mismatch
  + mount /run without MS_NOEXEC
  + dbus: fix name of capability property
  + systemctl: fix double unref of a dbus message
  + cryptsetup-generator: fix /etc/cryptsetup options
  + selinux: selinuxfs can be mounted on /sys/fs/selinux
  + readahead-common: fix total memory size detection
  + systemctl: fix 'is-enabled' for native units under /lib
  + systemctl: fix a FILE* leak
  + pam-module: add debug= parameter
  + remote-fs.target: do not order after network.target
- update tarball url.
* Wed Jun 15 2011 saschpe@suse.de
- Use RPM macros instead of $RPM_FOO variables
- Don't require %%{version}-%%{release} of the base package,
  %%{version} is sufficient
* Tue Jun 14 2011 kay.sievers@novell.com
- new snapshot
  - mount /run without MS_NOEXEC
  - readahead-common: fix total memory size detection
  - enable chkconfig support in systemctl for openSUSE
  - selinux: selinuxfs can be mounted on /sys/fs/selinux
  - cryptsetup-generator: fix /etc/cryptsetup options
  - systemctl: fix double unref of a dbus message
- drop merged chkconfig patch
* Tue Jun 14 2011 fcrozat@novell.com
- Add sysv chkconfig patch to be able to enable / disable sysv
  initscripts with systemctl.
- Ensure plymouth support is buildable conditionnally.
* Thu May 26 2011 kay.sievers@novell.com
- version 28
  - drop hwclock-save.service
  - fix segfault when a DBus message has no interface
  - man: update the list of unit search locations
  - readahead-collect: ignore EACCES for fanotify
  - rtc in localtime: use settimeofday(NULL, tz)
    instead of hwclock(8)
* Sat May 21 2011 kay.sievers@novell.com
- new snapshot
  - fix crash in D-Bus code
* Sat May 21 2011 kay.sievers@novell.com
- new snapshot
  - socket: always use SO_{RCV,SND}BUFFORCE to allow larger values
  - util: use new VT ESC sequence to clear scrollback buffer
  - sd-daemon: move _sd_hidden_ from .h to .c file
  - missing: add IP_TRANSPARENT
* Sat May 21 2011 kay.sievers@novell.com
- version 27
  - util: use open_terminal() in chvt() too
  - socket: expose SO_BROADCAST
  - git: add .mailmap
  - exec: expose tty reset options in dbus introspection data
  - socket: expose IP_TRANSPARENT
  - exec: hangup/reset/deallocate VTs in gettys
  - socket: use 666 socket mode by default since neither fifos,
    nor sockets, nor mqueues need to be executable
  - socket: add POSIX mqueue support
  - README: document relation to nss-myhostname
  - hostnamed: check that nss-myhostname is installed
* Tue May 17 2011 kay.sievers@novell.com
- new snapshot
  - sysctl: apply /etc/sysctl.conf last
  - systemd-analyze: print hostname, kernelversion and arch at
    the top of the plot
  - pam: downgrade a few log msgs
  - hostnamed: SetPrettyHostname() should check PK action
    org.freedesktop.hostname1.set-static-hostname
  - user-sessions: ignore EROFS when unlinking /etc/nologin if
    the file doesn't exist anyway
  - unit: make ignoring in snapshots a per unit property,
    instead of a per unit type property
  - vconsole: use open_terminal() instead of open()
  - units: enable automount units only if the kernel supports them
* Thu May  5 2011 coolo@opensuse.org
- remove policy filter
* Thu May  5 2011 meissner@suse.de
- add missing buildrequires dbus-1-devel, vala, libxslt-devel
- touch vala files for rebuilding to unbreak Factory
* Mon May  2 2011 kay.sievers@novell.com
- also delete plymouth files
* Mon May  2 2011 kay.sievers@novell.com
- disable plymouth sub-package until plymouth gets into Factory
* Sun May  1 2011 kay.sievers@novell.com
- new snapshot
  - binfmt, modules-load, sysctl, tmpfiles: add missing
    ConditionDirectoryNotEmpty=
  - binfmt, modules-load, sysctl, tmpfiles: read /usr/local/lib
    and where appropriate /lib directories
* Sat Apr 30 2011 kay.sievers@novell.com
- version 26
  - plymouth: introduce plymouth.enable=0 kernel command line
  - util: don't AND cx with cx
  - man: typo in sd_daemon reference
  - util: conf_files_list() return list as parameter
  - dbus: make daemon reexecution synchronous
* Thu Apr 28 2011 kay.sievers@novell.com
- new snapshot
  - service: properly notice when services with a main process
    that isn't a child of init die
  - unit: fix assert when trying to load unit instances for
    uninstanciable types
  - def: lower default timeout to 90s
  - manager: fix serialization counter
* Wed Apr 27 2011 kay.sievers@novell.com
- new snapshot
  - dbus: don't hit assert when dumping properties
  - cryptsetup: fix keyfile size option processing
  - socket: improve warning message when we get POLLHUP
  - mount: failure to mount cgroup hierarchies should not be fatal
  - configure: add AC_SYS_LARGEFILE
* Mon Apr 25 2011 kay.sievers@novell.com
- new snapshot
  - tmpfiles.d: switch to stacked config dirs in /lib, /etc, /run
  - sysctl.d, binfmt.d, modules-load.d: switch to stacked config
    dirs in /lib, /etc, /run
  - manager: mkdir /run/systemd/system when starting up
  - man: Spelling fixes
* Thu Apr 21 2011 kay.sievers@novell.com
- version 25
  - mount: Allow creating mount units for /var/lib/nfs/rpc_pipefs
    and /proc/fs/nfsd.
  - socket: support ListeSpecial= sockets
  - vconsole: don't set console font/keymap if settings are empty
  - nspawn: don't fail when we receive SIGCHLD
  - cgroup: don't accidentaly trim on reload
  - units: set capability bounding set for syslog services
  - socket: log more information about invalid poll events
  - man: fix specification of default timeouts
  - mount,crypto: rework meaning of noauto/nofail
  - fsck: don't fsck against basic.target in order to properly
    allow automount /home
  - manager: when running in test mode, do not write generated
    unit files to /run/systemd/generator
  - mount: properly parse timeouts options in the middle of
    the string
  - hostnamed: drop all caps but CAP_SYS_ADMIN
  - execute: when we run as PID 1 the kernel doesn't give us
    CAP_SETPCAP by default. Get that temporarily when dropping
    capabilities for good
  - mount: make device timeout configurable
  - cryptsetup: do not order crypto DM devices against the
    cryptsetup service
  - socket: reuse existing FIFOs
  - socket: guarantee order in which sockets are passed to be
    the one of the configuration file
  - systemctl: always consider unit files with no
    [Install] section but stored in /lib enabled
  - job: also print status messages when we successfully started
    a unit
  - hostnamed: add reference to SMBIOS specs
  - man: runlevel 5 is usually more comprehensive, so use it
    instead of 3 to detect whether a sysv service is enabled
  - polkit: follow the usual syntax for polkit actions
  - hostnamed: introduce systemd-hostnamed
  - units: order quotacheck after remount-rootfs
  - hostname: split out hostname validation into util.c
  - dbus: split out object management code into dbus-common,
    and simplify it
  - strv: properly override settings in env_append()
  - strv: detect non-assignments in env blocks properly in
    env_append()
  - strv: handle empty lists in strv_copy() properly
  - util: truncate newline inside of read_one_line_file()
  - util: modernize get_parent_of_pid() a bit
  - crypto: let the cryptsetup binary handles its own
    configurable timeouts
  - logger,initctl: use global exit timeout
  - ask-password: use default timeout
  - manager: drop all pending jobs when isolating
  - manager: introduce IgnoreOnIsolate flag so that we can keep
    systemd-logger around when isolating
  - units: never pull in sysinit from utmp, so that we can
    shutdown from emergency mode without pulling in sysinit
  - manager: downgrade a few log messages
  - units: require syslog.socket from the logger because we
    simply fail if we don't have it
  - logger: adjust socket description to match service
  - units: set stdout of kmsg syslogd to /dev/null
  - units: add --no-block when starting normal service after
    shell exited
  - ask-password: use kill(PID, 0) before querying a password
  - ask-password: support passwords without timeouts
  - ask-password: always send final NUL char
  - ask-password: properly accept empty passwords from agent
  - unit: skip default cgroup setup if we have no hierarchy
  - units: isolate emergency.target instead of emergency.service
    when we fail to mount all file systems
  - mount: don't pull in stdio logger for root mount unit
  - cgroup: be nice to Ingo Molnar
  - pam: use /proc/self/sessionid only with CAP_AUDIT_CONTROL
  - pam: use /proc/self/loginuid only with CAP_AUDIT_CONTROL
  - socket: try creating a socket under our own identity if we
    have no perms to consult the selinux database
  - socket: fix check for SEQPACKET
  - execute: don't fail if we cannot fix OOM in a container
  - unit: fix dump output
  - socket: be a bit more verbose when refusing to start a
    socket unit
  - socket: support netlink sockets
  - local-fs: invoke emergency.service mounting at boot fails
  - path: optionally, create watched directories in .path units
  - tmpfiles: don't warn if two identical lines are configured
  - man: add man page for ask-password
  - dbus: expose monotonic timestamps on the bus
  - manager: no need to use randomized generator dir when running
    as system manager
  - don't make up buffer sizes, use standard LINE_MAX instead
  - unit: disallow configuration of more than one on_failure
    dependencies if OnFailureIsolate= is on
  - unit: pull in logger unit only when running in system mode
  - manager: serialize/deserialize max job id and /usr taint flag
  - manager: don't garbage collect jobs when isolating, to change
    global state
  - unit: introduce OnFailureIsolate=
  - mount: relabel both before and after a mount, just in case
  - cmdline: we actually want to parse the kernel cmdline in VMs,
    just not in containers
  - units: rename rtc-set.target to time-sync.target and pull it
    in by hwclock-load.service
  - job: fix deserialization of jobs: do not ignore ordering
  - systemctl: properly parse JobNew signals
  - service: fix units with more than one socket
  - systemctl: make most operations NOPs in a chroot
  - manager: don't show PID for incoming signals if it is 0
  - man: fix description of systemctl reload-or-try-restart
  - mount: block creation of mount units for API file systems
  - units: call the logger a bridge too
  - build-sys: always place user units in /usr/lib/systemd
  - pkgconfig: update .pc file accordingly
  - lookup: always also look into /usr/lib for units
  - exec: support unlimited resources
  - selinux: relabel /run the same way as /dev after loading
    the policy since they both come pre-filled and unlabelled
  - manager: fd must be int, not char
  - change remaining /var/run to /run
  - units: move user units from /usr/share to /usr/lib since
    they might be arch-dependent
  - man: document /etc/sysctl.d/
  - binfmt: add binfmt tool to set up binfmt_misc at boot
  - tmpfiles: create leading directories for d/D instructions
  - condition: add ConditionSecurity
  - load-fragment: unify config_parse_condition_{kernel, virt}
  - condition: fix dumping of conditions
  - initctl: /dev/initctl is a named pipe, not a socket
  - kmsg-syslogd: pass facility value into kmsg
  - move /var/lock to HAVE_SYSV_COMPAT
  - tmpfiles: split off rules for legacy systems into legacy.conf
  - general: replace a few uses of /var/run by /run
  - tmpfiles: enforce new /var/lock semantics
  - man: document ConditionPathIsDirectory=
  - mount: also relabel pre-mounted API dirs
  - log: don't strip facility when writing to kmsg
  - build-sys: create a number of drop-in config dirs
  - random: do not print warning if random seed doesn't exist
  - plymouth: use PID file to detect whether ply is running
  - build-sys: install systemd-analyze by default
  - analyze: improve output
  - analyze: add plotter
  - unit: when deserializing do reconnect to dbus/syslog when
    they show up
  - analyze: beautify output a bit
  - add systemd-analyze tool
  - unit: don't override timestamps due to state changes when
    deserializing
  - plymouth: don't explicitly enable status message when
    plymouth is up
  - status: show status messages unconditionally if plymouth
    is around
  - taint: add missing cgroups taint flag
  - locale: don't access misinitialized variable
  - quota: do not pull in quota tools for mounts that do not
    originate in neither /etc/fstab nor fragment files
  - manager: fix taint check for /usr
  - unit: never apply /etc/rcN.d/ priority to native services
  - unit: fix parsing of condition-result
  - unit: don't complain about failed units when deserializing
  - exec: drop process group kill mode since it has little use
    and confuses the user
  - cgroup: explain when we cannot initialize the cgroup stuff
  - systemctl: don't truncate description when using pager
  - ask-password: also accept Backspace as first keypress as
    silent mode switch
  - unit: when deserializing jobs, don't pull in dependencies
  - locale: fix LC_MESSAGES variable name
  - plymouth: Remove the calls to plymouth message
  - udev: systemd-tag all ttys
  - tmpfiles fix /run/lock permissions
  - ask-password: use TAB to disable asterisk password echo
  - execute: socket isn't abstract anymore
  - use /run instead of /dev/.run
  - man: explain a couple of default dependencies
  - mount: pull in quota services from local mountpoints with
    usr/grpquota options
  - service: pull in sysv facility targets from the sysv units,
    not the other way round
  - units: pull in syslog.target from syslog.socket
  - units: don't ever pull in SysV targets from other SysV
    targets
  - units: document that some targets exists only for compat
    with SysV
  - man: document pidns containers
  - units: deemphesize Names= settings, and explain why nobody
    whould use them
  - units: on mandriva/fedora create single.service alias via
    symlink, not Names=
  - units: get rid of runlevel Names=, the symlinks in
    /lib/systemd/system are much more useful
  - rework syslog detection so that we need no compile-time
    option what the name of the syslog implementation is
  - man: document .requires/ directories
  - special: get rid of dbus.target
  - exec: properly apply capability bounding set, add inverted
    bounding sets
  - dbus: add service D-Bus property "Sockets"
  - dbus: consolidate service SysV conditionals
  - unit: serialize condition test results
  - def: centralize definition of default timeout in one place
  - chkconfig: check against runlevel 5 instead of 3, since it is
    a superset of the latter
  - systemctl: accept condstop as alias for stop
  - dbus: allow LoadUnit to unprivileged users
  - umount: make sure skip_ro is always correctly initialized
- create /run (link it to /var/run)
- refresh splash password patch
- conflict with old mkinitrd version (we need /run)
- conflict with old udev (we need /run)
* Wed Mar 16 2011 kay.sievers@novell.com
- new snapshot
  - man: fix systemctl try-restart description
  - Add Frugalware display-manager service
  - main: revert recognition of "b" argument
  - main: interpret all argv[] arguments unconditionally when
    run in a container
  - loopback: downgrade an error to warning
  - nspawn: bind mount /etc/localtime
  - nspawn: make tty code more robust against closed/reopened
    /dev/console
  - util: make touched files non-writable by default
  - nspawn: allocate a new pty instead of passing ours through
    to avoid terminal settings chaos
  - main: parse the whole arv[] as kernel command line
  - main: check if we have a valid PID before getting the name
  - ask-password: reset signal mask after we are done
  - cgroup: don't recheck all the time whether the systemd
    hierarchy is mounted, to make strace outputs nicer and save
    a few stat()s
  - man: document systemd-nspawn
  - cgls: don't strip user processes and kernel threads from
    default output
  - umount: don't try to remount bind mounts ro during shutdown
  - getty: move automatic serial getty logic into generator
  - container: skip a few things when we are run in a container
    such as accessing /proc/cmdline
  - cgls: by default start with group of PID 1
  - pam: determine user cgroup tree from cgroup of PID 1
  - nspawn: move container into its own name=systemd cgroup
  - manager: don't show kernel boot-up time for containers
  - manager: show who killed us
  - units: add console-shell.service which can be used insted of
    the gettys to get a shell on /dev/console
* Mon Mar 14 2011 kay.sievers@novell.com
- new snapshot
  - build-sys: move remaining tools from sbin/ to bin/ since they
    might eventually be useful for user execution
  - hostname: don't override the hostname with localhost if it
    is already set and /etc/hostname unset
  - audit: give up sending auditing messages when it failed due
    to EPERM
  - nspawn: don't require selinux on if it is compiled in
  - main: remove AF_UNIX sockets before binding
  - shutdown: print a nice message when terminating a container
  - nspawn: mount /selinux if needed
  - shutdown: just call exit() if we are in a container
  - umount: assume that a non-existing /dev/loop device means it
    is already detached
  - socket: use 777 as default mode for sockets
  - main: log to the console in a container
  - main: don't parse /proc/cmdline in containers
  - util: add detect_container()
  - nspawn: reset environment and load login shell
  - core: move abstract namespace sockets to /dev/.run
  - nspawn: add simple chroot(1) like tool to execute commands
    in a namespace container
  - util: return exit status in wait_for_terminate_and_warn()
  - util: properly identify pty devices by their major
* Sat Mar 12 2011 kay.sievers@novell.com
- new snapshot
  - polkit: autogenerate polkit policy with correct paths
  - systemctl: support remote and privileged systemctl access
    via SSH and pkexec
  - gnome-ask-password-agent: fix path to watch
* Fri Mar 11 2011 kay.sievers@novell.com
- fix broken sysctl.service linking
* Fri Mar 11 2011 kay.sievers@novell.com
- new snapshot
  - units: move the last flag files to /dev/.run
  - util: close all fds before freezing execution
  - dbus: timeout connection setup
  - main: properly handle -b boot option
  - pam: do not leak file descriptor if flock fails
- disable sysv services natively provided by systemd
* Thu Mar 10 2011 kay.sievers@novell.com
- new snapshot
  - main: refuse system to be started in a chroot
  - main: don't check if /usr really is a mount point, since it is
    fine if it is passed pre-mounted to us from the initrd
  - condition: take a timestamp and store last result of conditions
  - dev: use /dev/.run/systemd as runtime directory, instead of
    /dev/.systemd
  - machine-id: move machine-id-setup to /sbin
  - pkconfig: export full search path as .pc variable
  - selinux: bump up error level when in non-enforcing mode
  - dbus: fix dbus assert due to uninitialized error
  - dbus: properly generate UnknownInterface, UnknownProperty
    and PropertyReadOnly errors
  - mount: use /dev/.run as an early boot alias for /var/run
* Tue Mar  8 2011 kay.sievers@novell.com
- version 20
  - service: prefix description with LSB only if script has LSB header,
    use 'SysV:' otherwise
  - unit: don't accidently create ordering links to targets when
    default deps are off for either target and unit
  - mount: support less cumbersome x-systemd-xxx mount options
  - unit: distuingish mandatory from triggering conditions
  - dbus: return DBUS_ERROR_UNKNOWN_OBJECT when an object
    is unknown
  - systemctl: when forwarding is-enabled to chkconfig
    hardcode runlevel 3
  - job: introduce new job result code 'skipped' to use when pre
    conditions of job did not apply
  - job: convert job type as early as we can, to simplify things
  - Keep emacs configuration in one configuration file.
  - syslog: make sure the kmsg bridge is always pulled in and
    never terminated automatically
  - mount: make /media a tmpfs
* Mon Mar  7 2011 kay.sievers@novell.com
- new snapshot
  - add org.freedesktop.DBus.Properies.Set method
  - main: introduce /etc/machine-id
  - systemctl: fix exit code when directing is-enabled
    to chkconfig
  - dbus: add 'Tainted' property to Manager object
  - dbus: expose distribution name and features on manager
    object as properties
  - man: document changed EnvironmentFile= behaviour
  - main: add link to wiki page with longer explanation of the
    /usr madness
  - execute: load environment files at time of execution, not
    when we load the service configuration
  - path: after installing inotify watches, recheck file again
    to fix race
  - path: don't use IN_ATTRIB on parent dirs when watching a
    file, since those cannot be removed without emptying the dir
    first anyway and we need IN_ATTRIB only to detect the link
    count dropping to 0
  - kill: always send SIGCONT after SIGTERM
  - readahead: disable collector automatically on read-only media
  - sysctl: use scandir() instead of nftw() to guarantee
    systematic ordering
  - support DT_UNKNOWN where necessary for compat with reiserfs
  - systemctl: always null-terminate the password
- call systemd-machine-id-setup at installation
* Tue Mar  1 2011 kay.sievers@novell.com
- version 19
  - udev: don't ignore non-encrypted block devices with no
    superblock
  - udev: expose ttyUSB devices too
  - udev: mark hvc devices for exposure in systemd
  - cryptsetup: add a terse help
  - agent: don't print warnings if a password was removed or
    timed out
  - systemctl: shutdown agent explicitly so that it can reset
    the tty properly
  - never clean up a service that still has a process in it
  - label: udev might be making changes in /dev while we
    iterate through it
  - systemctl: properly handle job results
  - job: also trigger on-failure dependencies when jobs faile
    due to dependencies, timeout
  - job: when cancelling jobs, make sure to propagate this
    properly to depending jobs
  - job: start job timeout on enqueuing not when we start to
    process a job
  - unit: increase default timeout to 3min
  - logger: leave the logger longer around and allow it do
    handle more connections
  - dbus: pass along information why a job failed when it
    failed (dbus api change!)
  - general: unify error code we generate on timeout
  - units: synchronize gettys to plymouth even if plymouth is
    killed by gdm
  - job: start job timer when we begin running the job, not
    already when we add it to the queue of jobs
  - cryptsetup: try to show the mount point for a crypto disk
    if we can
  - rescue: terminate plymouth entirely when going into
    rescue mode
  - ask-password: fix handling of timeouts when waiting
    for password
  - ask-password: supported plymouth cached passwords
  - main: print warning if /usr is on a seperate partition
  - ensure we start not a single getty before plymouth is
    gone because we never know which ttys plymouth still controls
  - unit: introduce ConditionVirtualization=
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - dbus: don't rely that timer/path units have an initialized
    unit field (bnc#671561)
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - order network mounts after network.target (bnc#672855)
* Mon Feb 21 2011 kay.sievers@novell.com
- new snapshot
  - kmsg-syslogd: increase terminate timeout to 5min to generte
    less debug spew
  - shutdown(8) - call kexec if kexec kernel is loaded (bnc#671673)
  - unit: don't timeout fsck
  - man: fixed typo in SyslogIdentifier=
  - tmpfiles: never clean up block devices
  - main: refuse --test as root
* Fri Feb 18 2011 kay.sievers@novell.com
- new snapshot
  - units: order fsck@.service before basic.target
    instead of local-fs.target to relax things a little
  - readahead: remove misleading error messages
  - man: don't do more reloads than necessary in spec files
  - util: retry opening a TTY on EIO
  - util: beef up logic to find ctty name
  - tmpfiles: kill double slashes in unix socket names
- drop vhangup patch, it is fixed in login(3) by forwarding the
  SIGHUP to the child process
* Fri Feb 18 2011 coolo@novell.com
- revert back to conflicts: sysvinit
* Thu Feb 17 2011 werner@suse.de
- Add temporary workaround for bnc#652633, that is do a vhangup
  to all processes on a tty line used for a getty
* Wed Feb 16 2011 kay.sievers@novell.com
- version 18
  - systemctl: introduce --ignore-dependencies
  - systemctl: introduce --failed to show only failed services
  - systemctl: introduce --failed to show only failed services
  - rescue: make 'systemctl default' fail if there is already
    something running when the shell exited
  - util: seperate welcome line from other output by empty lines
  - manager: don't consider transaction jobs conflicting with
    queued jobs redundant
  - udev: ignore block devices which no known contents, to avoid
    trying of mounts/swapons when devices aren't set up full yet
  - swap: handle "nofail" from fstab
  - mount,swap: properly add dependencies to logger if needed
  - service: change default std output to inherit
  - exec: introduce global defaults for the standard output
    of services
  - udev: use SYSTEMD_READY to mask uninitialized DM devices
  - fsck: output to /dev/console by default in addition to syslog
  - execute: optionally forward program output to /dev/console in
    addition to syslog/kmsg
  - socket: refuse socket activation for SysV services
  - fsck: do not fail boot if fsck returns with an error code that
    hasn't 2 or 6 set
  - shutdown: execute all binaries in /lib/systemd/system-shutdown
    as last step before invoking reboot()
  - job: make status message printing more verbose
  - cryptsetup: fix unit file description
  - tmpfiles: never delete AF_UNIX sockets that are alive
  - getty: don't parse console= anymore, use
    /sys/class/tty/console/active instead
  - properly resolve /dev/console if more than once console=
    argument was passed on the kernel command line
  - getty: do not auto-spawn getty's on VC ttys if console=ttyN
  - fsck: skip root fsck if dracut already did it
  - util: when determining the right TERM for /dev/console
    consult /sys/class/tty/console/active
  - pam: introduce whitelist and blacklist user list feature
  - systemctl: minor optimizations
  - systemctl: don't unnecessarily close stdin/stdout/stderr for
    tty agent so that locking by tty works
  - readahead: disable readahead in virtual machines
  - tmpfiles: move binary to /bin to make it publicly available
  - tmpfiles: take names of tmpfiles configuration files on the
    command line
  - tmpfiles: log to stderr if possible
  - tmpfiles: support globs
  - units: introduce and hook up sound.target
  - dbus: allow all clients access to org.freedesktop.DBus.Peer
  - consider udev devices with SYSTEMD_READY=0 as unplugged
  - systemctl: don't start agent for --user
  - systemctl: make sure the tty agent does not retain a copy
    of stdio
* Tue Feb  8 2011 kay.sievers@novell.com
- new snapshot
  - plymouth: move plymouth out of TARGET_FEDORA
  - build-sys: fix AC_COMPILE_IFELSE tests
  - build-sys: ensure selinux configure check follows logic of
    other optional features
  - build-sys: autodetect and use pkg-config for libselinux
  - dbus: use ControlGroup as property name to match config option
  - pam: optionally reset cgroup memberships for login sessions
  - load-fragment: properly parse Nice= value
  - automount: use unit_pending_inactive() where appropriate
* Tue Feb  8 2011 jeffm@suse.de
- Removed unecessary workaround for plymouth startup.
* Fri Feb  4 2011 jeffm@suse.de
- Split plymouth support into systemd-plymouth package.
* Sat Jan 22 2011 kay.sievers@novell.com
- new snapshot
  - clang: fix some issues found with clang-analyzer
  - gcc: make gcc shut up
* Sat Jan 22 2011 kay.sievers@novell.com
- version 17
  - vala 0.10 seem to work fine
  - cryptsetup: fix ordering loop when dealing with encrypted
    swap devices
  - main: don't warn if /etc/mtab is a symlink to /proc/mounts
  - socket: don't crash if the .service unit for a .socket unit
    is not found
  - mount: ignore if an fsck is requested for a bind mount,
    so that we don't wait for the bind 'device' to show up
  - automount: fix segfault when shutting down
  - man: give an example for vconsole.conf
  - dbus: don't try to connect to the system bus before it is
    actually up
  - service: make chain of main commands and control commands
    independent of each other, so that both can be executed
    simultaneously and independently
  - service: don't allow reload operations for oneshot services
  - vala: convert from dbus-glib to gdbus
  - systemctl: highlight failed processes in systemctl status
  - systemctl: show process type along process exit codes
  - service: when reloading a service fails don't fail the entire
    service but just the reload job
* Wed Jan 19 2011 kay.sievers@novell.com
- new snapshot
  - shutdown: use correct kexec options
  - serial-getty: do not invoke /sbin/securetty; recent
    pam_securetty looks for console= in /proc/cmdline
  - systemctl: before spawning pager cache number of columns
  - pam: optionally keep processes of root user around
  - service: if a reload operation fails, don't shut down
    the service
  - execute: make sending of SIGKILL on shutdown optional
  - mount: do not translate uuids to lowercase
  - man: document missing KillSignal= and swap options
- require recent util-linux
- drop mtab symlink creation which is done in util-linux
* Sat Jan  8 2011 kay.sievers@novell.com
- version 16
  - device: don't warn if we cannot bump the udev socket buffer
  - logger: when passing on PID info, fall back to our own if
    originating process is already gone
  - service: don't hit an assert if information in LSB headers is
    incorrectly formatted
  - execute,util: fix two small memory leaks
  - getty: unset locale before execution
  - execute: drop empty assignments from env blocks on execution
    but keep them around otherwise to make them visible
  - umount: don't try to detach the dm device the root dir is on,
    to minimize warning messages
  - locale: fix variable names
  - fragment: allow prefixing of the EnvironmentFile=
    path with - to ignore errors
  - util: don't pass invalid fd to fdopendir() on error to avoid
    corruption of errno
  - tmpfiles: nicer message when two or more conflicting lines
    are configured for the same file
  - fragment: properly handle quotes in assignments in
    EnvironmentFile= files
  - sysctl: don't warn if sysctls are gone
  - readahead: ignore if files are removed during collection or
    before replay
  - serial: use TERM=vt100 instead of TERM=vt100-nav
  - cryptsetup: call mkswap on dm device, not on source device
  - mount-setup: mount /dev/pts with mode=620,gid=5 by default
    and make GID overridable via configure switch
  - systemctl: implement auto-pager a la git
  - shutdown: drop redundant sync() invocation
  - util: invoke sync() implicitly on freeze()
  - tmpfiles: do no follow symlinks when cleaning up dirs
* Tue Dec 28 2010 jeffm@suse.de
- Add support for building plymouth support with openSUSE
* Mon Dec 27 2010 kay.sievers@novell.com
- new snapshot
  - pam: do not sort user sessions into their own cgroups in
    the 'cpu' hierarchy
  - mount-setup: drop noexec flag from default mount options
    for /dev/shm
  - systemd.pc: change 'session' to 'user'
* Thu Dec 16 2010 kay.sievers@novell.com
- new snapshot
  - ifdef suse-only sysv script lookup code
* Thu Dec 16 2010 seife@opensuse.org
- add bootsplash handling patch to be able to enter e.g.
  crypto passphrases (bnc#659885)
* Thu Dec  9 2010 kay.sievers@novell.com
- new snapshot
  - add LSB 'smtp' alias for mail-transport-agent.target
* Wed Dec  8 2010 kay.sievers@novell.com
- new snapshot
  - path: fix watching the root directory
  - update README
* Fri Nov 26 2010 kay.sievers@novell.com
- new snapshot
  - gnome-ask-password-agent: also support libnotify < 0.7 for now
  - udev: increase event buffer size
- require fsck -l
* Thu Nov 25 2010 kay.sievers@novell.com
- version 15
  - dbus: use the right data slot allocator
  - manager: bump up max number of units to 128K
  - build-sys: allow cross-compilation
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Tue Nov 23 2010 kay.sievers@novell.com
- new snapshot
  - units: simplify shutdown scripts
  - logger: fix error handling
  - swap: order file-based swap devices after remount-rootfs
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Mon Nov 22 2010 kay.sievers@novell.com
- new snapshot
  - systemctl: don't return LSB status error codes for 'show'
  - mount: do not try to mount disabled cgroup controllers
  - man: document /etc/modules-load.d/, /etc/os-release,
    locale.conf, /etc/vconsole.conf, /etc/hostname
  - units: move a couple of units from base.target to
    sysinit.target
  - man: reorder things to follow the same order everywhere
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Sat Nov 20 2010 kay.sievers@novell.com
- version 13
  - cryptsetup: actually show disk name
  - cryptsetup: show udev device name when asking for password
  - sysctl: implement native tool and support /etc/sysctl.d
  - units: enable console ask-password agent by default
  - introduce /etc/os-release distro description
  - job: make sure we don't fail umount.target if a mount unit
    failed to stop
  - cgroup: after killing cgroup processes, ensure the group is
    really dead gone. wait for 3s at max
  - cgroup: if we couldn't remove a cgroup after killing
    evertyhing in it then it's fine
  - cryptsetup: automatically order crypt partitions before
    cryptsetup.target
  - man: trivial BindTo description fix
  - manager: make list of default controllers configurable
  - build: expose libcryptsetup dependency in build string
  - pam: document controllers= switch
  - cgroup: by default, duplicate service cgroup in the cpu hierarchy
  - pam: duplicate cgroup tree in the cpu hierarchy by default,
    optionally more
- enable native crypto handling instead of boot.crypto
- revert too new libnotify code/requirement
- revert fsck -l option requirement
* Wed Nov 17 2010 kay.sievers@novell.com
- version 12
  - ask-password: add --console mode to ask /dev/console
- revert too new libnotify code/requirement
* Tue Nov 16 2010 kay.sievers@novell.com
- new snapshot
  - cryptsetup: reword questions a little
  - units: order hwclock after readahead
  - path: don't mention too many inotify msgs
  - cryptsetup: include device name in password question
  - cryptsetup: lock ourselves into memory as long as we deal
    with passwords
  - plymouth: use updated socket name
  - units: set TERM for gettys again, since they acquire a TTY
  - units: allow start-up of plymouth ask-password agent very early
  - units: enable ask-paswword .path units early enough to be useful
    for early mounts
  - units: delay getty until logins are allowed
  - pam: always rely on loginuid instead of uid to determine cgroup
    and XDG_RUNTIME_DIR name
  - cgroup: call root cgroup system instead of systemd-1
  - exec: determine right TERM= setting based on tty name
  - pam: rename master user cgroup to 'master'
  - drop support for MANAGER_SESSION, introduce MANAGER_USER
  - units: use ConditionDirectoryNotEmpty= where applicable
  - unit: introduce ConditionDirectoryNotEmpty=
  - delete tmp.mount which may conflict with an unrelated fstab
    entry
- revert too new libnotify code/requirement
- disable native crypto handling
* Mon Nov 15 2010 kay.sievers@novell.com
- new snapshot
  - load-dropin: add support for .requires directories
  - manager: consider jobs already installed as redundant when
    reducing new transactions
  - manager: always pull 'following' units into transaction
  - util: always highlight distro name
  - units: make use of agetty mandatory
  - manager: don't fail transaction if adding CONFLICTED_BY job fails
  - job: make it possible to wait for devices to be unplugged
  - tmpfiles: ignore files marked with the sticky bit
  - cryptsetup: handle password=none properly
  - cryptsetup: properly parse cipher= switch
  - cryptsetup: support non-LUKS crypto partitions
  - ask-password: enable password agent
  - automatically start cryptsetup when looking for mount source
  - log: add automatic log target
  - cryptsetup: hook up tool with ask-password
  - manager: hookup generators
  - split mount_point_is_api() and mount_point_ignore()
- replace boot.crypto job with systemd native crypto handling
- enable readahead (requires 2.6.37+ kernel's fanotify to work)
* Thu Nov 11 2010 kay.sievers@novell.com
- new snapshot
  - tmpfiles: include reference to man page in tmpfiles files
  - vconsole: support additional keymap for toggling layouts
  - main: warn if /etc/mtab is not a symlink
  - add bash completion for systemctl --system
  - man: minor tmpfiles(5) updates and reindenting
  - main: rename process on startup to 'systemd' to avoid confusion
  - unit: add ConditionNull= condition
  - ac-power: make ac-power a proper binary that scripts can call
  - manager: parse RD_TIMESTAMP passed from initrd
  - modules-load: fix minor race
  - label: use internal utility functions wher epossible
  - cryptsetup: minimal cryptsetup unit generator
  - selinux: relabel /dev after loading policy
  - log: downgrade syslog connection failure message
  - service: delay automatic restart if job is pending
  - manager: when isolating undo all pending jobs, too
  - manager: only minimize impact if we are in fail mode
- replace /etc/mtab with link to /proc/self/mounts
* Thu Nov  4 2010 kay.sievers@novell.com
- new snapshot
  - man/tmpfiles.d.xml: add a manpage for tmpfiles
  - do not overwrite other udev tags
  - readahead: shortcut replay if /.readahead doesn't exist
* Fri Oct 29 2010 kay.sievers@novell.com
- new snapshot
  - fsck: return SUCCESS when we skip the check
  - fsck: skip checking / if it is writable
  - units: fix variable expansion
  - mount: don't pull in nofail mounts by default, but use them
    if they are around
  - job: recursively fail BoundBy dependencies
  - fsck: fix target name to check for
  - units: rename fedora/single.service to rescue.service
  - units: introduce plymouth-start and plymouth-kexec
  - unit: get rid of IgnoreDependencyFailure=
  - use util-linux:agetty instead of mingetty
  - unit: replace StopRetroactively= by BindTo= dependencies
  - automount: show who's triggering an automount
  - units: run sysctl only if /etc/sysctl.conf exists
  - systemctl: always show what and where for mount units
  - shutdown: reword a few messages a little
  - manager: show which jobs are actually installed after a transaction
  - timer: when deserializing timer state stay elapsed
  - device: set recursive_stop=true by default
  - unit: suppress incorrect deserialization errors
  - swap: there's no reason not order swap after sysinit
  - socket: fix IPv6 availability detection
* Wed Oct 27 2010 kay.sievers@novell.com
- new snapshot
  - create /dev/stderr and friends early on boot
  - run sysv related scripts with TERM=linux
  - add only swaps listed in /etc/fstab automatically to swap.target
  - errors: refer to systemctl status when useful
  - swap: add default cgroup to swap exec env
  - readahead: bump a device's request_nr when enabling readahead
  - shutdown: properly handle sigtimedwait() timing out
  - main: fix typo in kernel cmdline parameters help
  - ord-tty: properly handle SIGINT/SIGTERM
  - systemctl: automatically spawn temporary password agent
  - ask-password: properly handle multiple pending passwords
  - ask-password: enable plymouth agent by default
  - ask-password: add minimal plymouth password agent
* Tue Oct 26 2010 kay.sievers@novell.com
- new snapshot
  - make sure to pass TERM=linux to all sysv scripts
  - don't unset HOME/TERM when run in session mode
  - mount: add nosuid,nodev,noexec switches to /var/lock and /var/run
  - tmpfiles: Don't clean /var/lock/subsys
  - tmpfiles: Make wtmp match utmp perms, and add btmp
  - umount: Make sure / is remounted ro on shutdown
  - unset HOME and TERM set from the kernel
  - activate wall agent automatically
  - ask-password: add basic tty agent
* Sat Oct 23 2010 kay.sievers@novell.com
- new snapshot
  - rename ask-password-agent to gnome-ask-password-agent
  - fsck: suppress error message if we cannot change into single
    user mode since
  - dbus: epose FsckPassNo property for service objects
  - man: document systemctl --force
  - introduce 'systemctl kill'
* Sat Oct 23 2010 kay.sievers@novell.com
- new snapshot
  - syslog: enable kmsg bridge by default
  - fsck: add initial version of fsck and quotacheck wrappers
  - tmpfiles: remove forcefsck/fastboot flag files after boot
  - swap: listen for POLLPRI events on /proc/swaps if availabled
  - tmpfiles: integrate native tmpwatch
  - shutdown: loop only as long as we manage to unmount/detach devices
  - umount: disable dm devices by devnode, not by path name
  - introduce final.target
  - replace distro-specific shutdown scripts with native services
  - try to get rid of DM devices
  - log to console by default
  - introduce kexec.service, kexec.target and exit.target
  - hook in fsck@.service instance for all mount points with passno > 0
  - systemctl: warn if user enables unit with no installation instructions
  - dbus: add introspection to midlevel paths
  - look for dynamic throw-away units in /dev/.systemd/system
  - major rework, use /sbin/swapon for setting up swaps
  - introduce Restart=on-failure and Restart=on-abort
  - units: enable utmp for serial gettys too
  - rename 'banned' load state to 'masked'
  - optionally, create INIT_PROCESS/DEAD_PROCESS entries for a service
- use systemd-native fsck/mount
- use systemd-native tmpfiles.d/ instead of tmpwatch
* Fri Oct  8 2010 kay.sievers@novell.com
  new snapshot
  - fix 'systemctl enable getty@.service'
  - properly support 'banning' of services
  - handle nologin
  - add native reboot/shutdown implementation
* Thu Oct  7 2010 kay.sievers@novell.com
- version 11
* Wed Oct  6 2010 kay.sievers@novell.com
- new snapshot
  - readahead fixes
* Sun Oct  3 2010 aj@suse.de
- /etc/modules.d was renamed to modules-load.d
- only include tmpfiles.d/*conf files
* Wed Sep 29 2010 kay.sievers@novell.com
- don't create sysv order deps on merged units
- fix Provides: handling in LSB headers (network.target)
- native (optional) readahead
* Sun Sep 26 2010 aj@suse.de
- Do not package man pages twice.
* Wed Sep 22 2010 kay.sievers@novell.com
- new snapshot
  - basic services are enabled by default now
* Tue Sep 21 2010 kay.sievers@novell.com
- new snapshot
  - vconsole and locale setup
  - hook up tmpwatch
* Fri Sep 17 2010 kay.sievers@novell.com
- new snapshot
  - add new utility to initialize the virtual console
  - initialize locale from /etc/locale by default
  - ask-password: allow services query SSL/harddisk passphrases
* Fri Sep 17 2010 kay.sievers@novell.com
- version 10
  - logger: support SOCK_STREAM /dev/log sockets
  - make sure the file system is writable before we write utmp data
  - systemctl: use isolate when called as telinit for a runlevel
  - initctl: properly use isolate when activating runlevels
  - set HOME=/root when running shells
  - make sure we don't crash if there's an automount unit without
    mount unit
  - start logger only after syslog is up
* Fri Sep  3 2010 kay.sievers@novell.com
- version 9
  - units: don't add shutdown conflicts dep to umount.target
  - dbus: don't send cgroup agent messages directly to system bus
  - dbus: don't accept activation requests anymore if we are going
    down anyway
  - systemctl: fix return value of systemctl start and friends
  - service: wait for process exit only if we actually killed
    somebody
* Thu Aug 26 2010 kay.sievers@novell.com
- version 8
  - KERNEL 2.6.36+ REQUIRED!
  - mount cgroup file systems to /sys/fs/cgroup instead of /cgroup
  - invoke sulogin instead of /bin/sh
  - systemctl: show timestamps for state changes
  - add global configuration options for handling of auto mounts
* Fri Aug 20 2010 kay.sievers@novell.com
- apply /etc/fstab mount options to all api mounts
- properly handle LABEL="" in fstab
- do not consider LSB exit codes 5 and 6 as failure
* Tue Aug 17 2010 kay.sievers@novell.com
- prefix sysv job descriptions with LSB:
- add native sysctl + hwclock + random seed service files
- properly fallback to rescue.target if default.target is hosed
- rename ValidNoProcess= to RemainAfterExit=
- add systemd-modules-load tool to handle /etc/modules.d/
* Tue Aug 17 2010 kay.sievers@novell.com
- add support for delayed shutdown, similar to sysv in style
- rename Type=finish to Type=oneshot and allow multiple ExecStart=
- don't show ENOENT for non exitent configuration files
- log build time features on startup
- rearrange structs to make them smaller
- move runlevel[2-5] links to /lib
- create default.target link to /lib not /etc
- handle random-seed
- write utmp record before we kill all processes
- create /var/lock/subsys, /var/run/utmp
* Wed Aug 11 2010 kay.sievers@novell.com
- add audit messages for service changes
- update utmp with external program
- all to refuse manual service starting/stopping
* Tue Aug 10 2010 kay.sievers@novell.com
- version 7
  - hide output if quiet is passed on the kernel cmdline
  - fix auto restarting of units after a configuration reload
  - don't call bus_path_escape() with NULL unit name
* Fri Aug  6 2010 kay.sievers@novell.com
- version 6
  - man page update
* Fri Aug  6 2010 kay.sievers@novell.com
- new snapshot
  - downgrade a few log messages
  - properly handle devices which are referenced before they exist
* Thu Aug  5 2010 kay.sievers@novell.com
- new snapshot
  - fix dependency cycle of boot.* by splitting fsck.target
  - sort boot.* before other sysv services
    from sysinint.target
  - start getty for serial console
* Thu Aug  5 2010 kay.sievers@novell.com
- add licence to subpackages
* Wed Aug  4 2010 kay.sievers@novell.com
- version 5
  - selinux fixes
- fix hanging 'reboot' started from vc
* Mon Aug  2 2010 kay.sievers@novell.com
- enable getty.target by default
* Sat Jul 24 2010 kay.sievers@novell.com
- at install, read old inittab for the defaul target/runlevel
- disable services on package uninstall
* Sat Jul 24 2010 kay.sievers@novell.com
- version 4
  - merge systemd-install into systemctl
* Fri Jul 23 2010 kay.sievers@novell.com
- create config files in /etc in %%post
- mark files in /etc as config
- remove nodev from /dev/pts
- add selinux support
* Thu Jul 22 2010 kay.sievers@novell.com
- version 4 (pre)
  - require newer vala
  - add [Install] section to getty.target and remote-fs.target
- re-enable post-build check
* Wed Jul 21 2010 kay.sievers@novell.com
- do not add sysv services that are not enabled in /etc/rcN.d/
- allow symlinking unit files to /dev/null
- remove only pam sessions we ourselves created
- unit files in /etc/ always take precedence, even over link targets
* Tue Jul 20 2010 kay.sievers@novell.com
- fix access mode verification of FIFOs
* Sun Jul 18 2010 kay.sievers@novell.com
- fix default mode of /var/run and /var/lock
- force /var/run and /var/lock to be on tmpfs
* Wed Jul 14 2010 kay.sievers@novell.com
- always enable udev and dbus until we can require systemd from
  packages providing systemd service files
* Tue Jul 13 2010 kay.sievers@novell.com
- drop systemd-units.rpm
* Tue Jul 13 2010 kay.sievers@novell.com
- version 3
  - treat non-existing cgroups like empty ones, to deal with races
  - replace --running-as= by --session and --system
  - always allow stopping of units that failed to load
* Tue Jul 13 2010 kay.sievers@novell.com
- update
* Mon Jul 12 2010 kay.sievers@novell.com
- drop libcgroup
* Mon Jul 12 2010 kay.sievers@novell.com
- trim cgroups for services that are "active" but "exited"
- drop /bin/init hack and require now fixed mkinitrd
* Sun Jul 11 2010 kay.sievers@novell.com
- fix reboot issue
- fix abstract namespace name handling (needs udev update)
- prefer private D-Bus socket wherever possible
* Sat Jul 10 2010 kay.sievers@novell.com
- D-Bus 1.3.2 support
- use COLD_BOOT=1 on reboot to skip sysv boot.d/ handling
* Fri Jul  9 2010 kay.sievers@novell.com
- fix typo in spec file
* Fri Jul  9 2010 kay.sievers@novell.com
- provide /bin/init to be found by 'too simple' mkinitrd, and work
  around mindless relinking of relative links in the buildsystem
- add rpmlintrc to silent warnings about intentional behavior
* Fri Jul  9 2010 kay.sievers@novell.com
- version 2
* Thu Jul  8 2010 kay.sievers@novell.com
- fix 'reboot -w' to skip the actual reboot
- fix segfault in D-Bus code
- use unique instead of multiple keys in config file
- support continuation lines in config files
- support multiple commands in a single key in config files
- adapt log level of some messages
* Wed Jul  7 2010 kay.sievers@novell.com
- version 1
  - default log level to INFO
  - show welcome message
* Tue Jul  6 2010 kay.sievers@novell.com
- add systemd-install --start option
- add more documentation
* Mon Jul  5 2010 kay.sievers@novell.com
- new snapshot with extended D-Bus support
* Sun Jul  4 2010 kay.sievers@novell.com
- new snapshot with default unit dependency handling
* Sat Jul  3 2010 kay.sievers@novell.com
- new snapshot
* Fri Jul  2 2010 kay.sievers@novell.com
- add more documentation
* Thu Jul  1 2010 kay.sievers@novell.com
- new snapshot
* Thu Jun 24 2010 kay.sievers@novell.com
- split off systemd-units.rpm which can be pulled-in by other
  packages without further dependencies
* Thu Jun 24 2010 kay.sievers@novell.com
- add more documentation
* Tue Jun 22 2010 kay.sievers@novell.com
- more man pages and documentation
* Tue Jun 22 2010 kay.sievers@novell.com
- conflict with upstart
- include all installed doc files
* Tue Jun 22 2010 kay.sievers@novell.com
- provide pam module
* Mon Jun 21 2010 kay.sievers@novell.com
- use private D-Bus connection
- properly handle replacing a running upstart
* Fri Jun 18 2010 kay.sievers@novell.com
- implement wall message in halt/reboot/...
- speak /dev/initctl to old /sbin/init after installing
* Thu Jun 17 2010 kay.sievers@novell.com
- drop no longer needed -fno-strict-aliasing
- add README and examples
* Thu Jun 17 2010 kay.sievers@novell.com
- enable pam and libwrap
* Thu Jun 17 2010 kay.sievers@novell.com
- provide systemd-sysvinit.rpm with /sbin/init and friends
* Thu Jun 17 2010 kay.sievers@novell.com
- libwrap / pam support
* Wed Jun 16 2010 kay.sievers@novell.com
- initial packaging of experimental version 0
